pub struct HitResult {
pub id: usize,
pub z: i32,
pub kind: HitKind,
pub shape: HitShape,
pub transform: Transform2D,
pub region_id: Option<u32>,
pub local_pos: Option<[f32; 2]>,
pub local_uv: Option<[f32; 2]>,
}Expand description
Result of a hit test for a single topmost element.
Fields
id: usizeIncreasing draw-order identifier within the display list.
z: i32Z layering value; larger is visually on top.
kind: HitKindKind of primitive that was hit.
shape: HitShapeGeometry of the hit shape.
transform: Transform2DThe local-to-world transform at draw time.
region_id: Option<u32>If this hit corresponds to a hit region, returns the user-specified region id.
local_pos: Option<[f32; 2]>Local point within the hit item’s local space (after inverse transform), relative to the shape’s origin.
local_uv: Option<[f32; 2]>Normalized coordinates within the shape’s bounding box when applicable ([0,1] range).