pub struct OverlaySolidRenderer { /* private fields */ }Expand description
Solid renderer variant for overlays that do not participate in depth testing.
Uses the same SOLID_WGSL shader and vertex layout as BasicSolidRenderer, but
disables depth-stencil so overlay quads simply blend over existing content.
Implementations
Sourceimpl OverlaySolidRenderer
impl OverlaySolidRenderer
pub fn new(device: Arc<Device>, target_format: TextureFormat) -> Self
pub fn viewport_bgl(&self) -> &BindGroupLayout
pub fn record<'a>( &'a self, pass: &mut RenderPass<'a>, vp_bg: &'a BindGroup, vbuf: &'a Buffer, ibuf: &'a Buffer, icount: u32, )